package com.fs.course.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.course.domain.FsCourseQuestionCategory;

/**
 * 题目分类Mapper接口
 * 
 * @author fs
 * @date 2025-04-17
 */
public interface FsCourseQuestionCategoryMapper extends BaseMapper<FsCourseQuestionCategory>{
    /**
     * 查询题目分类
     * 
     * @param cateId 题目分类主键
     * @return 题目分类
     */
    FsCourseQuestionCategory selectFsCourseQuestionCategoryByCateId(Long cateId);

    /**
     * 查询题目分类列表
     * 
     * @param fsCourseQuestionCategory 题目分类
     * @return 题目分类集合
     */
    List<FsCourseQuestionCategory> selectFsCourseQuestionCategoryList(FsCourseQuestionCategory fsCourseQuestionCategory);

    /**
     * 新增题目分类
     * 
     * @param fsCourseQuestionCategory 题目分类
     * @return 结果
     */
    int insertFsCourseQuestionCategory(FsCourseQuestionCategory fsCourseQuestionCategory);

    /**
     * 修改题目分类
     * 
     * @param fsCourseQuestionCategory 题目分类
     * @return 结果
     */
    int updateFsCourseQuestionCategory(FsCourseQuestionCategory fsCourseQuestionCategory);

    /**
     * 删除题目分类
     * 
     * @param cateId 题目分类主键
     * @return 结果
     */
    int deleteFsCourseQuestionCategoryByCateId(Long cateId);

    /**
     * 批量删除题目分类
     * 
     * @param cateIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsCourseQuestionCategoryByCateIds(Long[] cateIds);
}
